==> xl-react-components-0.16.62.tgz: package/app/xl-react-dip/xl-react-dip-lookup/xl-react-dip-lookup.js <==
import R from 'ramda';
import React, {PureComponent} from 'react';
import PropTypes from 'prop-types';
import {OverlayTrigger, Popover} from 'react-bootstrap';
import {localeMessages} from '../../services/locale-service';
import {computeInitialState, computeNextPropsState, getValidators} from '../../services/component-service';
import {getModelValue, resetPristinity} from '../../utils/components-utils';
import RU from '../../utils/ramda-utils';
import {XlReactWidgetInputAddon} from '../../xl-react-widget/xl-react-widget-input-addon/xl-react-widget-input-addon';
import {XlReactWidgetInputAddonGroup} from '../../xl-react-widget/xl-react-widget-input-addon/xl-react-widget-input-addon-group'; // eslint-disable-line max-len
import {XlReactWidgetSwitch} from '../../xl-react-widget/xl-react-widget-switch/xl-react-widget-switch';
import {XlReactWidgetSwitchButton} from '../../xl-react-widget/xl-react-widget-switch/xl-react-widget-switch-button/xl-react-widget-switch-button'; // eslint-disable-line max-len
import {XlReactDipCi} from '../xl-react-dip-ci/xl-react-dip-ci';
import {XlReactDipContainerProps} from '../xl-react-dip-props';
import {XlReactDipString} from '../xl-react-dip-string/xl-react-dip-string';
import {lookupModelType} from './xl-react-dip-lookup-type';
import {apiFocus} from './xl-react-dip-lookup-service';

import './xl-react-dip-lookup.less';

const omitRegister = (props) => R.omit(['register'], props);

export class XlReactDipLookup extends PureComponent {
    static propTypes = {
        fieldComponent: PropTypes.func.isRequired,
        handlers: PropTypes.object.isRequired,
        model: lookupModelType,
        onLookupToggle: PropTypes.func.isRequired,
        ...XlReactDipContainerProps
    };

    state = {};

    componentWillMount() {
        RU.invoke('register', [this.api], this.props);
        const model = getModelValue(this.props, 'model', '');
        computeInitialState(this, this.props, getValidators(this.props), model);
    }

    componentWillReceiveProps(nextProps) {
        computeNextPropsState(this, nextProps, this.state, getValidators(nextProps));
    }

    handleLookupChange = R.curry((field, value) => {
        RU.invoke('onModelChange', [R.assoc(field, value, this.props.model)], this.props);
    });

    handleMessageChange = (value) => {
        RU.invoke('onMessageChange', [value], this.props);
    };

    handleProviderChange = (value) => {
        RU.invoke(['key', 'markAsDirty'], [], this.componentApis);
        this.handleLookupChange('provider')(value);
    };

    handlePristinityChange = (value) => {
        RU.invoke('onPristinityChange', [value], this.props);
    };

    handleValidityLookupChange = (field) => (value) => {
        this.valid = {...this.valid, [field]: value};
        RU.invoke('onValidityChange', [value], this.props);
    };

    api = {
        focus: () => apiFocus(this),
        isPristine: () => this.state.pristine,
        resetPristinity: (config) => {
            resetPristinity(this, this.props, config);
            R.pipe(
                R.keys,
                R.forEach((key) => {
                    this.componentApis[key].resetPristinity(config);
                })
            )(this.componentApis);
        }
    };

    componentApis = {};

    lookupClassName = 'xl-react-dip-lookup';

    lookupPopover = <Popover
        className="tooltip-popover"
        id="xl-react-dip-lookup-popover">
        {localeMessages.dipLookupToggleTooltipMessage}
    </Popover>;

    valid = {};

    registerApi = (field) => (api) => {
        this.componentApis[field] = api;
    };

    unregisterApi = (field) => () => {
        this.componentApis = R.omit([field], this.componentApis);
    };

    isLookupField = () => R.propSatisfies(R.is(Object), 'model', this.props);

    renderSwitch = () => {
        const {onLookupToggle, disabled} = this.props;
        return <XlReactWidgetInputAddonGroup>
            <XlReactWidgetInputAddon>
                <XlReactWidgetSwitch
                    disabled={disabled}
                    model={this.isLookupField()}
                    onModelChange={onLookupToggle}
                    onPristinityChange={this.handlePristinityChange}
                    renderSwitch={({className}) =>
                        <XlReactWidgetSwitchButton className={className}>
                            <OverlayTrigger
                                overlay={this.lookupPopover}
                                placement="top"
                                trigger={['focus', 'hover', 'click']}>
                                <div className="xl-dip-lookup-switch-icon"/>
                            </OverlayTrigger>
                        </XlReactWidgetSwitchButton>
                    }
                />
            </XlReactWidgetInputAddon>
        </XlReactWidgetInputAddonGroup>;
    };

    renderLookupFields = () => {
        const {
            disabled,
            displayMode,
            handlers,
            metadata,
            model: {key, provider}
        } = this.props;

        const {message} = this.state;

        const required = metadata.required || Boolean(key) || Boolean(provider);

        const providerMetadata = {
            ...metadata,
            asRequired: required,
            description: undefined
        };
        const keyMetadata = {
            ...metadata,
            asRequired: required,
            label: ' ',
            password: false,
            required: false,
            size: 'DEFAULT',
            type: 'text'
        };

        return <React.Fragment>
            <XlReactDipCi
                className={this.lookupClassName}
                controlClassName="xl-react-dip-lookup-control"
                disabled={disabled}
                displayMode={displayMode}
                handlers={handlers}
                metadata={providerMetadata}
                model={provider}
                onMessageChange={this.handleMessageChange}
                onModelChange={this.handleProviderChange}
                onPristinityChange={this.handlePristinityChange}
                onValidityChange={this.handleValidityLookupChange('provider')}
                register={this.registerApi('provider')}
                showSearchIcon={false}
                toggleButton={this.renderSwitch()}
                unregister={this.unregisterApi('provider')}
            />
            <XlReactDipString
                disabled={disabled}
                displayMode={displayMode}
                message={message}
                metadata={keyMetadata}
                model={key}
                onMessageChange={this.handleMessageChange}
                onModelChange={this.handleLookupChange('key')}
                onPristinityChange={this.handlePristinityChange}
                onValidityChange={this.handleValidityLookupChange('key')}
                register={this.registerApi('key')}
                unregister={this.unregisterApi('key')}
            />
        </React.Fragment>;
    };

    render() {
        const {fieldComponent: FieldComponent, ...rest} = this.props;

        if (this.isLookupField()) {
            this.unregisterApi('baseField');
            return this.renderLookupFields();
        }

        this.unregisterApi('key');
        this.unregisterApi('provider');
        return <FieldComponent
            {...omitRegister(rest)}
            className={this.lookupClassName}
            onPristinityChange={this.handlePristinityChange}
            register={this.registerApi('baseField')}
            toggleButton={this.renderSwitch()}
        />;
    }
}

==> xl-react-components-0.18.103.tgz: package/app/xl-react-dip/xl-react-dip-lookup/xl-react-dip-lookup.js <==
import R from 'ramda';
import React, {PureComponent} from 'react';
import PropTypes from 'prop-types';
import {OverlayTrigger, Popover} from 'react-bootstrap';
import {localeMessages} from '../../services/locale-service';
import {computeInitialState, computeNextPropsState, getValidators} from '../../services/component-service';
import {resetPristinity} from '../../utils/components-utils';
import RU from '../../utils/ramda-utils';
import {XlReactWidgetInputAddon} from '../../xl-react-widget/xl-react-widget-input-addon/xl-react-widget-input-addon';
import {XlReactWidgetInputAddonGroup} from '../../xl-react-widget/xl-react-widget-input-addon/xl-react-widget-input-addon-group'; // eslint-disable-line max-len
import {XlReactWidgetSwitch} from '../../xl-react-widget/xl-react-widget-switch/xl-react-widget-switch';
import {XlReactWidgetSwitchButton} from '../../xl-react-widget/xl-react-widget-switch/xl-react-widget-switch-button/xl-react-widget-switch-button'; // eslint-disable-line max-len
import {XlReactDipCi} from '../xl-react-dip-ci/xl-react-dip-ci';
import {XlReactDipContainerProps} from '../xl-react-dip-props';
import {XlReactDipString} from '../xl-react-dip-string/xl-react-dip-string';
import {lookupModelType} from './xl-react-dip-lookup-type';
import {apiFocus} from './xl-react-dip-lookup-service';

import './xl-react-dip-lookup.less';

const omitRegister = (props) => R.omit(['register'], props);

export class XlReactDipLookup extends PureComponent {
    static propTypes = {
        fieldComponent: PropTypes.func.isRequired,
        handlers: PropTypes.object.isRequired,
        model: lookupModelType,
        onLookupToggle: PropTypes.func.isRequired,
        ...XlReactDipContainerProps
    };

    state = {};

    componentWillMount() {
        RU.invoke('register', [this.api], this.props);
        computeInitialState(this, this.props, getValidators(this.props), this.props.model);
    }

    componentWillReceiveProps(nextProps) {
        computeNextPropsState(this, nextProps, this.state, getValidators(nextProps));
    }

    handleLookupChange = R.curry((field, value) => {
        RU.invoke('onModelChange', [R.assoc(field, value, this.props.model)], this.props);
    });

    handleMessageChange = (value) => {
        RU.invoke('onMessageChange', [value], this.props);
    };

    handleProviderChange = (value) => {
        RU.invoke(['key', 'markAsDirty'], [], this.componentApis);
        this.handleLookupChange('provider')(value);
    };

    handlePristinityChange = (value) => {
        RU.invoke('onPristinityChange', [value], this.props);
    };

    handleValidityLookupChange = (field) => (value) => {
        this.valid = {...this.valid, [field]: value};
        RU.invoke('onValidityChange', [value], this.props);
    };

    api = {
        focus: () => apiFocus(this),
        isPristine: () => this.state.pristine,
        resetPristinity: (config) => {
            resetPristinity(this, this.props, config);
            R.pipe(
                R.keys,
                R.forEach((key) => {
                    this.componentApis[key].resetPristinity(config);
                })
            )(this.componentApis);
        }
    };

    componentApis = {};

    lookupClassName = 'xl-react-dip-lookup';

    lookupPopover = <Popover
        className="tooltip-popover"
        id="xl-react-dip-lookup-popover">
        {localeMessages.dipLookupToggleTooltipMessage}
    </Popover>;

    valid = {};

    registerApi = (field) => (api) => {
        this.componentApis[field] = api;
        RU.invoke('register', [this.api], this.props);
    };

    unregisterApi = (field) => () => {
        this.componentApis = R.omit([field], this.componentApis);
        RU.invoke('register', [this.api], this.props);
    };

    isLookupField = () => R.propSatisfies(R.is(Object), 'model', this.props);

    renderSwitch = () => {
        const {onLookupToggle, disabled} = this.props;
        return <XlReactWidgetInputAddonGroup>
            <XlReactWidgetInputAddon>
                <XlReactWidgetSwitch
                    disabled={disabled}
                    model={this.isLookupField()}
                    onModelChange={onLookupToggle}
                    onPristinityChange={this.handlePristinityChange}
                    renderSwitch={({className}) =>
                        <XlReactWidgetSwitchButton className={className}>
                            <OverlayTrigger
                                overlay={this.lookupPopover}
                                placement="top"
                                trigger={['focus', 'hover', 'click']}>
                                <div className="xl-dip-lookup-switch-icon"/>
                            </OverlayTrigger>
                        </XlReactWidgetSwitchButton>
                    }
                />
            </XlReactWidgetInputAddon>
        </XlReactWidgetInputAddonGroup>;
    };

    renderLookupFields = () => {
        const {
            disabled,
            displayMode,
            handlers,
            metadata,
            model: {key, provider}
        } = this.props;

        const {message} = this.state;

        const required = metadata.required || Boolean(key) || Boolean(provider);

        const providerMetadata = {
            ...metadata,
            asRequired: required,
            description: undefined
        };
        const keyMetadata = {
            ...metadata,
            asRequired: required,
            label: ' ',
            password: false,
            required: false,
            size: 'DEFAULT',
            type: 'text'
        };

        return <React.Fragment>
            <XlReactDipCi
                className={this.lookupClassName}
                controlClassName="xl-react-dip-lookup-control"
                disabled={disabled}
                displayMode={displayMode}
                handlers={handlers}
                metadata={providerMetadata}
                model={provider}
                onMessageChange={this.handleMessageChange}
                onModelChange={this.handleProviderChange}
                onPristinityChange={this.handlePristinityChange}
                onValidityChange={this.handleValidityLookupChange('provider')}
                register={this.registerApi('provider')}
                showSearchIcon={false}
                toggleButton={this.renderSwitch()}
                unregister={this.unregisterApi('provider')}
            />
            <XlReactDipString
                disabled={disabled}
                displayMode={displayMode}
                message={message}
                metadata={keyMetadata}
                model={key}
                onMessageChange={this.handleMessageChange}
                onModelChange={this.handleLookupChange('key')}
                onPristinityChange={this.handlePristinityChange}
                onValidityChange={this.handleValidityLookupChange('key')}
                register={this.registerApi('key')}
                unregister={this.unregisterApi('key')}
            />
        </React.Fragment>;
    };

    render() {
        const {fieldComponent: FieldComponent, ...rest} = this.props;

        if (this.isLookupField()) {
            this.unregisterApi('baseField');
            return this.renderLookupFields();
        }

        this.unregisterApi('key');
        this.unregisterApi('provider');
        return <FieldComponent
            {...omitRegister(rest)}
            className={this.lookupClassName}
            onPristinityChange={this.handlePristinityChange}
            register={this.registerApi('baseField')}
            toggleButton={this.renderSwitch()}
            unregister={this.unregisterApi('baseField')}
        />;
    }
}
